==> texlive-core-2016.43757-1-any.pkg.tar.xz: usr/share/texmf-dist/scripts/latexindent/LatexIndent/Tokens.pm <==
package LatexIndent::Tokens;
#	This program is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation, either version 3 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	See http://www.gnu.org/licenses/.
#
#	Chris Hughes, 2017
#
#	For all communication, please visit: https://github.com/cmhughes/latexindent.pl
use strict;
use warnings;
use Exporter qw/import/;
use LatexIndent::Switches qw/$is_t_switch_active $is_tt_switch_active/;
our @EXPORT_OK = qw/token_check %tokens/;

# each of the tokens begins the same way -- this is exploited during the hidden Children routine
my $beginningToken = "LTXIN-TK-";
my $ifelsefiSpecial = "!-!";

# the %tokens hash is passed around many modules
our %tokens = (
                environment=>$beginningToken."ENVIRONMENT",
                ifelsefiSpecial=>$ifelsefiSpecial,
                ifelsefi=>$ifelsefiSpecial.$beginningToken."IFELSEFI", 
                item=>$beginningToken."ITEMS",
                trailingComment=>"latexindenttrailingcomment", 
                blanklines=>$beginningToken."blank-line",
                arguments=>$beginningToken."ARGUMENTS",
                optionalArgument=>$beginningToken."OPTIONAL-ARGUMENT",
                mandatoryArgument=>$beginningToken."MANDATORY-ARGUMENT",
                roundBracket=>$beginningToken."ROUND-BRACKET",
                verbatim=>$beginningToken."VERBATIM",
                command=>$beginningToken."COMMAND",
                key_equals_values_braces=>$beginningToken."KEY-VALUE-BRACES",
                groupingBraces=>$beginningToken."GROUPING-BRACES",
                unNamedgroupingBraces=>$beginningToken."UN-NAMED-GROUPING-BRACES",
                special=>$beginningToken."SPECIAL",
                heading=>$beginningToken."HEADING",
                filecontents=>$beginningToken."FILECONTENTS",
                preamble=>$beginningToken."preamble",
                beginOfToken=>$beginningToken,
                doubleBackSlash=>$beginningToken."DOUBLEBACKSLASH",
                alignmentBlock=>$beginningToken."ALIGNMENTBLOCK",
                endOfToken=>"-END",
              );

sub token_check{
    my $self = shift;

    $self->logger("Token check",'heading') if $is_t_switch_active;
    # we use tokens for trailing comments, environments, commands, etc, so check that they're not in the body
    foreach( keys %tokens){
        while(${$self}{body} =~ m/$tokens{$_}/si){
            $self->logger("Found $tokens{$_} within body, updating replacement token to $tokens{$_}-LIN") if($is_t_switch_active);
            $tokens{$_} .= "-LIN";
        }
    }
}


1;

==> texlive-core-2017.44918-1-any.pkg.tar.xz: usr/share/texmf-dist/scripts/latexindent/LatexIndent/Tokens.pm <==
package LatexIndent::Tokens;
#	This program is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation, either version 3 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	See http://www.gnu.org/licenses/.
#
#	Chris Hughes, 2017
#
#	For all communication, please visit: https://github.com/cmhughes/latexindent.pl
use strict;
use warnings;
use Exporter qw/import/;
use LatexIndent::Switches qw/$is_t_switch_active $is_tt_switch_active/;
our @EXPORT_OK = qw/token_check %tokens/;

# each of the tokens begins the same way -- this is exploited during the hidden Children routine
my $beginningToken = "LTXIN-TK-";
my $ifelsefiSpecial = "!-!";

# the %tokens hash is passed around many modules
our %tokens = (
                # user-facing naming convention
                environments=>$beginningToken."ENVIRONMENT",
                commands=>$beginningToken."COMMAND",
                optionalArguments=>$beginningToken."OPTIONAL-ARGUMENT",
                mandatoryArguments=>$beginningToken."MANDATORY-ARGUMENT",
                ifElseFi=>$ifelsefiSpecial.$beginningToken."IFELSEFI", 
                items=>$beginningToken."ITEMS",
                keyEqualsValuesBracesBrackets=>$beginningToken."KEY-VALUE-BRACES",
                namedGroupingBracesBrackets=>$beginningToken."GROUPING-BRACES",
                UnNamedGroupingBracesBrackets=>$beginningToken."UN-NAMED-GROUPING-BRACES",
                specialBeginEnd=>$beginningToken."SPECIAL",
                afterHeading=>$beginningToken."HEADING",
                filecontents=>$beginningToken."FILECONTENTS",
                # internal-facing naming convention
                trailingComment=>"latexindenttrailingcomment", 
                ifelsefiSpecial=>$ifelsefiSpecial,
                blanklines=>$beginningToken."blank-line",
                arguments=>$beginningToken."ARGUMENTS",
                roundBracket=>$beginningToken."ROUND-BRACKET",
                verbatim=>$beginningToken."VERBATIM",
                preamble=>$beginningToken."preamble",
                beginOfToken=>$beginningToken,
                doubleBackSlash=>$beginningToken."DOUBLEBACKSLASH",
                alignmentBlock=>$beginningToken."ALIGNMENTBLOCK",
                paragraph=>$beginningToken."PARA",
                endOfToken=>"-END",
              );

sub token_check{
    my $self = shift;

    $self->logger("Token check",'heading') if $is_t_switch_active;
    # we use tokens for trailing comments, environments, commands, etc, so check that they're not in the body
    foreach( keys %tokens){
        while(${$self}{body} =~ m/$tokens{$_}/si){
            $self->logger("Found $tokens{$_} within body, updating replacement token to $tokens{$_}-LIN") if($is_t_switch_active);
            $tokens{$_} .= "-LIN";
        }
    }
}


1;
